@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 import re
 import platform
+import warnings
 
 import pep8
 
 from flake8 import __version__
 from flake8 import callbacks
-from flake8.reporter import multiprocessing, BaseQReport, QueueReport
-from flake8.util import OrderedSet, is_windows, is_using_stdin
+from flake8.reporter import (multiprocessing, BaseQReport, FileQReport,
+                             QueueReport)
+from flake8 import util
 
 _flake8_noqa = re.compile(r'\s*# flake8[:=]\s*noqa', re.I).search
 
@@ -16,7 +18,7 @@ EXTRA_EXCLUDE = ['.tox', '.eggs', '*.egg']
 
 def _register_extensions():
     """Register all the extensions."""
-    extensions = OrderedSet()
+    extensions = util.OrderedSet()
     extensions.add(('pep8', pep8.__version__))
     parser_hooks = []
     options_hooks = []
@@ -122,10 +124,25 @@ def get_style_guide(**kwargs):
     for options_hook in options_hooks:
         options_hook(options)
 
+    if util.warn_when_using_jobs(options):
+        if not multiprocessing:
+            warnings.warn("The multiprocessing module is not available. "
+                          "Ignoring --jobs arguments.")
+        if util.is_windows():
+            warnings.warn("The --jobs option is not available on Windows. "
+                          "Ignoring --jobs arguments.")
+        if util.is_using_stdin(styleguide.paths):
+            warnings.warn("The --jobs option is not compatible with supplying "
+                          "input using - . Ignoring --jobs arguments.")
+        if options.diff:
+            warnings.warn("The --diff option was specified with --jobs but "
+                          "they are not compatible. Ignoring --jobs arguments."
+                          )
+
     if options.diff:
         options.jobs = None
 
-    force_disable_jobs = is_windows() or is_using_stdin(styleguide.paths)
+    force_disable_jobs = util.force_disable_jobs(styleguide)
 
     if multiprocessing and options.jobs and not force_disable_jobs:
         if options.jobs.isdigit():
@@ -137,7 +154,11 @@ def get_style_guide(**kwargs):
                 n_jobs = 1
         if n_jobs > 1:
             options.jobs = n_jobs
-            reporter = BaseQReport if options.quiet else QueueReport
+            reporter = QueueReport
+            if options.quiet:
+                reporter = BaseQReport
+                if options.quiet == 1:
+                    reporter = FileQReport
             report = styleguide.init_report(reporter)
             report.input_file = styleguide.input_file
             styleguide.runner = report.task_queue.put
